==> libunwind_1.2.1.orig.tar.gz: libunwind-1.2.1/src/coredump/_UCD_accessors.c <==
/* libunwind - a platform-independent unwind library

This file is part of libunwind.

Permission is hereby granted, free of charge, to any person obtaining
a copy of this software and associated documentation files (the
"Software"), to deal in the Software without restriction, including
without limitation the rights to use, copy, modify, merge, publish,
distribute, sublicense, and/or sell copies of the Software, and to
permit persons to whom the Software is furnished to do so, subject to
the following conditions:

The above copyright notice and this permission notice shall be
included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.  */

#include "_UCD_internal.h"

PROTECTED unw_accessors_t _UCD_accessors =
  {
    .find_proc_info             = _UCD_find_proc_info,
    .put_unwind_info            = _UCD_put_unwind_info,
    .get_dyn_info_list_addr     = _UCD_get_dyn_info_list_addr,
    .access_mem                 = _UCD_access_mem,
    .access_reg                 = _UCD_access_reg,
    .access_fpreg               = _UCD_access_fpreg,
    .resume                     = _UCD_resume,
    .get_proc_name              = _UCD_get_proc_name
  };

==> libunwind-1.5.0.tar.gz: libunwind-1.5.0/src/coredump/_UCD_accessors.c <==
/* libunwind - a platform-independent unwind library

This file is part of libunwind.

Permission is hereby granted, free of charge, to any person obtaining
a copy of this software and associated documentation files (the
"Software"), to deal in the Software without restriction, including
without limitation the rights to use, copy, modify, merge, publish,
distribute, sublicense, and/or sell copies of the Software, and to
permit persons to whom the Software is furnished to do so, subject to
the following conditions:

The above copyright notice and this permission notice shall be
included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.  */

#include "_UCD_internal.h"

unw_accessors_t _UCD_accessors =
  {
    .find_proc_info             = _UCD_find_proc_info,
    .put_unwind_info            = _UCD_put_unwind_info,
    .get_dyn_info_list_addr     = _UCD_get_dyn_info_list_addr,
    .access_mem                 = _UCD_access_mem,
    .access_reg                 = _UCD_access_reg,
    .access_fpreg               = _UCD_access_fpreg,
    .resume                     = _UCD_resume,
    .get_proc_name              = _UCD_get_proc_name
  };
